@@ -1,9 +1,12 @@
 # encoding: utf-8
 
+#--------------------------------------------------------------------------
 # Gather everything into a convenient namespace
+#--------------------------------------------------------------------------
 
 from evdev.device import DeviceInfo, InputDevice, AbsInfo
 from evdev.events import InputEvent, KeyEvent, RelEvent, SynEvent, AbsEvent, event_factory
 from evdev.uinput import UInput, UInputError
 from evdev.util import list_devices, categorize, resolve_ecodes
 from evdev import ecodes
+from evdev import ff
